@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -56,7 +56,21 @@ class Repository(Entity):
       be a string
     """
 
-    # TODO: Add OpenLDAP support, or at least learn how those stuff works.
+    #
+    # TODO: Add OpenLDAP support.
+    #
+    # In an OpenLDAP Server + AutoFS setup Stalker can create new entries to
+    # OpenLDAP server.
+    #
+    # The AutoFS can be installed to any linux system easily or it is already
+    # installed. OSX has it already. I know nothing about Windows.
+    #
+    # AutoFS can be setup to listen for new mount points from an OpendLDAP
+    # server. Thus it is heavily related with the users system, Stalker
+    # can not do anything about that. The IT should setup workstations.
+    #
+    # But Stalker can connect to the OpenLDAP server and create new entries.
+    #
 
     __auto_name__ = False
     __tablename__ = 'Repositories'
@@ -87,10 +101,11 @@ class Repository(Entity):
         """validates the given linux path
         """
         if not isinstance(linux_path_in, (str, unicode)):
-            raise TypeError("%s.linux_path should be an instance of string "
-                            "or unicode not %s" %
-                            (self.__class__.__name__,
-                             linux_path_in.__class__.__name__))
+            raise TypeError(
+                "%s.linux_path should be an instance of string or unicode not "
+                "%s" %
+                (self.__class__.__name__, linux_path_in.__class__.__name__)
+            )
 
         linux_path_in = os.path.normpath(linux_path_in) + '/'
 
@@ -101,10 +116,10 @@ class Repository(Entity):
         """validates the given osx path
         """
         if not isinstance(osx_path_in, (str, unicode)):
-            raise TypeError("%s.osx_path should be an instance of string or "
-                            "unicode not %s" %
-                            (self.__class__.__name__,
-                             osx_path_in.__class__.__name__))
+            raise TypeError(
+                "%s.osx_path should be an instance of string or unicode not %s"
+                % (self.__class__.__name__, osx_path_in.__class__.__name__)
+            )
 
         osx_path_in = os.path.normpath(osx_path_in) + '/'
 
@@ -115,10 +130,11 @@ class Repository(Entity):
         """validates the given windows path
         """
         if not isinstance(windows_path_in, (str, unicode)):
-            raise TypeError("%s.windows_path should be an instance of string "
-                            "or unicode not %s" %
-                            (self.__class__.__name__,
-                             windows_path_in.__class__.__name__))
+            raise TypeError(
+                "%s.windows_path should be an instance of string or unicode "
+                "not %s" %
+                (self.__class__.__name__, windows_path_in.__class__.__name__)
+            )
 
         windows_path_in = os.path.normpath(windows_path_in) + '/'
 
