@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -50,12 +50,12 @@ class SchedulerBase(object):
         """
         if studio_in is not None:
             from stalker import Studio
-
             if not isinstance(studio_in, Studio):
-                raise TypeError('%s.studio should be an instance of '
-                                'stalker.models.studio.Studio, not %s' %
-                                (self.__class__.__name__,
-                                 studio_in.__class__.__name__))
+                raise TypeError(
+                    '%s.studio should be an instance of '
+                    'stalker.models.studio.Studio, not %s' %
+                    (self.__class__.__name__, studio_in.__class__.__name__)
+                )
         return studio_in
 
     @property
@@ -80,14 +80,90 @@ class SchedulerBase(object):
 class TaskJugglerScheduler(SchedulerBase):
     """This is the main scheduler for Stalker right now.
 
-    Integrates Stalker and TaskJuggler together by using TaskJugglerScheduler
-    to solve the scheduling problem.
+    This class prepares the data for TaskJuggler and let it solve the
+    scheduling problem, and then retrieves the solved date and resource data
+    back.
+
+    TaskJugglerScheduler needs a :class:`.Studio` instance to work with, it
+    will create a .tjp file and then solve the tasks and restore the
+    computed_start and computed_end dates and the computed_resources
+    attributes for each task.
+
+    Stalker will pass all its data to TaskJuggler by creating a tjp file that
+    TaskJuggler can parse. This tjp file has all the Projects, Tasks, Users,
+    Departments, TimeLogs, Vacations and everything that TJ need for solving
+    the tasks. With every new version of it, Stalker tries to cover more and
+    more TaskJuggler directives.
+
+    .. note::
+       .. versionadded:: 0.2.5
+          Alternative Resources
+
+       Stalker is now able to pass alternative resources to TaskJuggler.
+       Although, per resource alternatives are not yet possible, it will be
+       implemented in future versions of Stalker.
+
+    .. note::
+       .. versionadded:: 0.2.5
+          Task Dependency Relation Attributes
+
+       Stalker now can use 'gapduration', 'gaplength', 'onstart' and 'onend'
+       TaskJuggler directives for each dependent task of a task. Use the
+       TaskDependency instance in Task.task_dependency attribute to control how
+       a particular task is depending to another task.
+
+    .. warning::
+       **Task.computed_resources Attribute Content**
+
+       After the scheduling is finished, TaskJuggler will create a ``csv``
+       report that TaskJugglerScheduler will parse. This csv file contains the
+       ``id``, ``start date``, ``end date`` and ``resources`` data. The
+       resources reported back by TJ will be stored in
+       :attr:`.Task.computed_resources` attribute.
+
+       TaskJuggler will put all the resources who may have entered a
+       :class:`.TimeLog` previously to the csv file. But the resources from the
+       csv file may not be in :attr:`.Task.resources` or
+       :attr:`.Task.alternative_resources` anymore. Because of that,
+       TaskJugglerScheduler will only store the resources those are both in csv
+       file and in :attr:`.Task.resources` or
+       :attr:`.Task.alternative_resources` attributes.
+
+    Stalker will export each Project to tjp as the highest task in the
+    hierarchy and all the projects will be combined in to the same tjp file.
+    Combining all the Projects in one tjp file has a very nice side effect,
+    projects using the same resources will respect their allocations to the
+    resource. So that when a TaskJugglerScheduler instance is used to schedule
+    the project, all projects are scheduled together.
+
+    The following table shows which Stalker data type is converted to which
+    TaskJuggler type:
+    
+      +------------+-------------+
+      | Stalker    | TaskJuggler |
+      +============+=============+
+      | Studio     | Project     |
+      +------------+-------------+
+      | Project    | Task        |
+      +------------+-------------+
+      | Task       | Task        |
+      +------------+-------------+
+      | Asset      | Task        |
+      +------------+-------------+
+      | Shot       | Task        |
+      +------------+-------------+
+      | Sequence   | Task        |
+      +------------+-------------+
+      | Departmemt | Resource    |
+      +------------+-------------+
+      | User       | Resource    |
+      +------------+-------------+
+      | TimeLog    | Booking     |
+      +------------+-------------+
+      | Vacation   | Vacation    |
+      +------------+-------------+
+      
 
-    TaskJugglerScheduler needs a :class:`~stalker.models.studio.Studio`
-    instance to work with. TJS will create a .tjp file and then solve the tasks
-    and restore the computed_start and computed_end dates. Combining all the
-    Projects in one tjp file has a very nice side effect, projects using the
-    same resources will respect their allocations to the resource.
     """
 
     def __init__(self, studio=None):
@@ -165,6 +241,8 @@ class TaskJugglerScheduler(SchedulerBase):
         computed end values
         """
         logger.debug('csv_file_full_path : %s' % self.csv_file_full_path)
+        from stalker import User  #, Task
+        # from stalker.db import DBSession
 
         with open(self.csv_file_full_path, 'r') as self.csv_file:
             csv_content = csv.reader(self.csv_file, delimiter=';')
@@ -173,9 +251,8 @@ class TaskJugglerScheduler(SchedulerBase):
             for data in lines:
                 id_line = data[0]
                 entity_id = int(id_line.split('.')[-1].split('_')[-1])
-                #logger.debug('updating entity with id : %s' % entity_id)
                 entity = Entity.query.filter(Entity.id == entity_id).first()
-                #logger.debug('updating : %s' % entity)
+                # tasks = Task.__table__
                 if entity:
                     start_date = datetime.datetime.strptime(
                         data[1], "%Y-%m-%d-%H:%M"
@@ -184,32 +261,62 @@ class TaskJugglerScheduler(SchedulerBase):
                         data[2],
                         "%Y-%m-%d-%H:%M"
                     )
-                    #logger.debug('   start : %s' % start_date)
-                    #logger.debug('     end : %s' % end_date)
+
+                    # computed_resources
+                    resources_data = map(
+                        lambda x: x.split('_')[-1].split(')')[0],
+                        data[3].split(',')
+                    )
+                    computed_resources = \
+                        User.query.filter(User.id.in_(resources_data)).all()
 
                     entity.computed_start = start_date
                     entity.computed_end = end_date
-                    #logger.debug('updated : %s' % entity)
+                    entity.computed_resources = computed_resources
+                    # update_statement = tasks.update().values({
+                    #     tasks.c.start: start_date,
+                    #     tasks.c.end: end_date,
+                    #     tasks.c.computed_start: start_date,
+                    #     tasks.c.computed_end: end_date
+                    # }).where(tasks.c.id == entity_id)
+                    # DBSession.connection().execute(update_statement)
         logger.debug('completed parsing csv file')
 
     def schedule(self):
-        """does the scheduling
+        """Does the scheduling.
         """
         # check the studio attribute
         from stalker import Studio
 
         if not isinstance(self.studio, Studio):
-            raise TypeError('%s.studio should be an instance of '
-                            'stalker.models.studio.Studio, not %s' %
-                            (self.__class__.__name__,
-                             self.studio.__class__.__name__))
+            raise TypeError(
+                '%s.studio should be an instance of '
+                'stalker.models.studio.Studio, not %s' %
+                (self.__class__.__name__, self.studio.__class__.__name__)
+            )
 
         # ********************************************************************
-        # Adjust Studio.start and Studio.end
-        # get the active projects
-        # get root tasks
-        # calculate the earliest start and the latest end
         # TODO: remove the hardcoded datetime
+        #
+        # Adjust Studio.start:
+        # 1- Looking at the earliest TimeLog entry for all of the active
+        #    Projects. If, there are no TimeLogs, use today 0:00.
+        # 2- Update the Studio.start if the project that have the earliest
+        #    TimeLog has been deactivated.
+        #
+        # Adjust Studio.end:
+        # 1- If the Studio.end is None, set it to Studio.start
+        # 2- Add 1 month to Studio.end
+        # 3- Schedule it.
+        # 4- If TaskJuggler complains about that some of the tasks doesn't fit
+        #    in to the time range, or some of the task marked as non scheduled,
+        #    increment the Studio.end by 2 months.
+        # 5- If TaskJuggler complains again then increment 3 months, and then
+        #    5, 8, 13, 21... that is the fibonacci series.
+        # 6- When TaskJuggler is successful on scheduling the projects, reset
+        #    the increment counter, and use this new date until TJ starts to
+        #    complain again.
+        #
         self.studio._start = datetime.datetime(2013, 1, 1)
         self.studio._end = datetime.datetime(2016, 1, 1)
         #for project in self.studio.active_projects:
