@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -22,7 +22,7 @@ import unittest2
 import datetime
 from stalker import (Project, Repository, Status, StatusList, Task, TimeLog,
                      User)
-from stalker.exceptions import OverBookedError
+from stalker.exceptions import OverBookedError, StatusError
 
 
 class TimeLogTester(unittest2.TestCase):
@@ -60,11 +60,8 @@ class TimeLogTester(unittest2.TestCase):
             target_entity_type=Project
         )
 
-        self.test_task_status_list = StatusList(
-            name="Task Statuses",
-            statuses=[self.test_status1, self.test_status2, self.test_status3],
-            target_entity_type=Task
-        )
+        self.test_task_status_list = StatusList.query\
+            .filter_by(target_entity_type='Task').first()
 
         self.test_project = Project(
             name="test project",
@@ -97,7 +94,7 @@ class TimeLogTester(unittest2.TestCase):
         """
         self.assertTrue(TimeLog.__auto_name__)
 
-    def test_task_argument_is_Skipped(self):
+    def test_task_argument_is_skipped(self):
         """testing if a TypeError will be raised when the task argument is
         skipped
         """
@@ -272,7 +269,7 @@ class TimeLogTester(unittest2.TestCase):
         self.assertEqual(self.test_time_log.resource, new_resource)
 
     def test_ScheduleMixin_initialization(self):
-        """testing if the ScheduleMixin part is initialized correctly
+        """testing if the DateRangeMixin part is initialized correctly
         """
         # it should have schedule attributes
         self.assertEqual(self.test_time_log.start,
@@ -493,6 +490,16 @@ class TimeLogDBTestCase(unittest2.TestCase):
         db.setup()
         db.init()
 
+        self.status_wfd = Status.query.filter_by(code='WFD').first()
+        self.status_rts = Status.query.filter_by(code='RTS').first()
+        self.status_wip = Status.query.filter_by(code='WIP').first()
+        self.status_prev = Status.query.filter_by(code='PREV').first()
+        self.status_hrev = Status.query.filter_by(code='HREV').first()
+        self.status_drev = Status.query.filter_by(code='DREV').first()
+        self.status_oh = Status.query.filter_by(code='OH').first()
+        self.status_stop = Status.query.filter_by(code='STOP').first()
+        self.status_cmpl = Status.query.filter_by(code='CMPL').first()
+
         # create a resource
         self.test_resource1 = User(
             name="User1",
@@ -521,11 +528,8 @@ class TimeLogDBTestCase(unittest2.TestCase):
             target_entity_type=Project
         )
 
-        self.test_task_status_list = StatusList(
-            name="Task Statuses",
-            statuses=[self.test_status1, self.test_status2, self.test_status3],
-            target_entity_type=Task
-        )
+        self.test_task_status_list = StatusList.query\
+            .filter_by(target_entity_type='Task').first()
 
         self.test_project = Project(
             name="test project",
@@ -556,7 +560,7 @@ class TimeLogDBTestCase(unittest2.TestCase):
         """testing timeLog prevents auto flush when expanding task
         schedule_timing attribute
         """
-        from stalker.db import DBSession
+        from stalker.db.session import DBSession
 
         tlog1 = TimeLog(**self.kwargs)
         DBSession.add(tlog1)
@@ -613,7 +617,7 @@ class TimeLogDBTestCase(unittest2.TestCase):
         child_task2.parent = parent_task1
         child_task1.parent = parent_task2
 
-        from stalker.db import DBSession
+        from stalker.db.session import DBSession
 
         self.assertEqual(parent_task1.total_logged_seconds, 0)
         self.assertEqual(parent_task2.total_logged_seconds, 0)
@@ -688,3 +692,94 @@ class TimeLogDBTestCase(unittest2.TestCase):
         self.assertEqual(parent_task2.total_logged_seconds, 9 * 3600)
         self.assertEqual(child_task1.total_logged_seconds, 9 * 3600)
         self.assertEqual(child_task2.total_logged_seconds, 12 * 3600)
+
+    def test_time_log_creation_for_a_WFD_leaf_task(self):
+        """testing if a StatusError will be raised when a TimeLog instance
+        wanted to be created for a WFD leaf task
+        """
+        new_task = Task(
+            name='Test Task 2',
+            project=self.test_project
+        )
+        new_task.depends = [self.test_task]
+        self.kwargs['task'] = new_task
+        self.assertRaises(StatusError, TimeLog, **self.kwargs)
+
+    def test_time_log_creation_for_a_RTS_leaf_task(self):
+        """testing if the status will be updated to WIP when a TimeLog instance
+        is created for a RTS leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_rts
+        self.assertEqual(task.status, self.status_rts)
+        TimeLog(**self.kwargs)
+        self.assertEqual(task.status, self.status_wip)
+
+    def test_time_log_creation_for_a_WIP_leaf_task(self):
+        """testing if the status will stay at WIP when a TimeLog instance is
+        created for a WIP leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_wip
+        self.assertEqual(task.status, self.status_wip)
+        TimeLog(**self.kwargs)
+
+    def test_time_log_creation_for_a_PREV_leaf_task(self):
+        """testing if a StatusError will be raised when a TimeLog instance is
+        created for a PREV leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_prev
+        self.assertEqual(task.status, self.status_prev)
+        self.assertRaises(StatusError, TimeLog, **self.kwargs)
+
+    def test_time_log_creation_for_a_HREV_leaf_task(self):
+        """testing if the status will be updated to WIP when a TimeLog instance
+        is created for a HREV leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_hrev
+        self.assertEqual(task.status, self.status_hrev)
+        TimeLog(**self.kwargs)
+
+    def test_time_log_creation_for_a_DREV_leaf_task(self):
+        """testing if the status will stay at DREV when a TimeLog instance is
+        created for a DREV leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_drev
+        self.assertEqual(task.status, self.status_drev)
+        TimeLog(**self.kwargs)
+
+    def test_time_log_creation_for_a_OH_leaf_task(self):
+        """testing if a StatusError will be raised when a TimeLog instance is
+        created for a OH leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_oh
+        self.assertEqual(task.status, self.status_oh)
+        self.assertRaises(StatusError, TimeLog, **self.kwargs)
+
+    def test_time_log_creation_for_a_STOP_leaf_task(self):
+        """testing if a StatusError will be raised when a TimeLog instance is
+        created for a STOP leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_stop
+        self.assertEqual(task.status, self.status_stop)
+        self.assertRaises(StatusError, TimeLog, **self.kwargs)
+
+    def test_time_log_creation_for_a_CMPL_leaf_task(self):
+        """testing if a StatusError will be raised when a TimeLog instance is
+        created for a CMPL leaf task
+        """
+        task = self.kwargs['task']
+        task.status = self.status_cmpl
+        self.assertEqual(task.status, self.status_cmpl)
+        self.assertRaises(StatusError, TimeLog, **self.kwargs)
+
+    def test_time_log_creation_that_violates_dependency_condition(self):
+        """testing if a ValueError will be raised when the entered TimeLog will
+        violate the dependency relation of the task
+        """
+        self.fail('test is not implemented yet')
